@@ -1,6 +1,5 @@
 /*
     SPDX-FileCopyrightText: 2019 Andreas Cord-Landwehr <cordlandwehr@kde.org>
-
     SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */
 
@@ -22,11 +21,14 @@ class ARTIKULATECORE_EXPORT IEditablePhrase : public IPhrase
     Q_PROPERTY(QString id READ id NOTIFY idChanged)
     Q_PROPERTY(QString text READ text NOTIFY textChanged)
     Q_PROPERTY(QString i18nText READ i18nText NOTIFY i18nTextChanged)
-    Q_PROPERTY(QString soundFileUrl READ soundFileUrl NOTIFY soundChanged)
     Q_PROPERTY(IPhrase::Type type READ type NOTIFY typeChanged)
 
 public:
-    enum class EditState { Unknown, Translated, Completed };
+    enum class EditState {
+        Unknown,
+        Translated,
+        Completed
+    };
     Q_ENUM(EditState)
 
     ~IEditablePhrase() override = default;
@@ -37,7 +39,6 @@ public:
     virtual void seti18nText(QString text) = 0;
     virtual void setUnit(std::shared_ptr<IUnit> unit) = 0;
     virtual void setType(IPhrase::Type type) = 0;
-    virtual void setSoundFileUrl() = 0; // TODO revisit as a setter should have an argument
     virtual IEditablePhrase::EditState editState() const = 0;
     virtual QString editStateString() const = 0;
     virtual void setEditState(IEditablePhrase::EditState state) = 0;
