@@ -1,12 +1,9 @@
 /*
     SPDX-FileCopyrightText: 2013 Andreas Cord-Landwehr <cordlandwehr@kde.org>
-
     SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */
 
 #include "language.h"
-#include "artikulate_debug.h"
-#include "models/languagemodel.h"
 #include "phoneme.h"
 #include "phonemegroup.h"
 #include <KLocalizedString>
@@ -25,34 +22,34 @@ std::shared_ptr<Language> Language::create(QUrl file)
         xml.setDevice(&handle);
         xml.readNextStartElement();
         while (xml.readNext() && !xml.atEnd()) {
-            if (xml.name() == "id") {
+            if (xml.name() == QLatin1String("id")) {
                 language->setId(xml.readElementText());
             }
-            if (xml.name() == "title") {
+            if (xml.name() == QLatin1String("title")) {
                 language->setTitle(xml.readElementText());
             }
-            if (xml.name() == "i18nTitle") {
+            if (xml.name() == QLatin1String("i18nTitle")) {
                 language->seti18nTitle(xml.readElementText());
             }
-            if (xml.name() == "phonemeGroup") {
+            if (xml.name() == QLatin1String("phonemeGroup")) {
                 std::shared_ptr<PhonemeGroup> group = std::shared_ptr<PhonemeGroup>(new PhonemeGroup);
-                while (xml.readNext() && !xml.atEnd() && xml.name() != "phonemeGroup") {
-                    if (xml.name() == "id") {
+                while (xml.readNext() && !xml.atEnd() && xml.name() != QLatin1String("phonemeGroup")) {
+                    if (xml.name() == QLatin1String("id")) {
                         group->setId(xml.readElementText());
                     }
-                    if (xml.name() == "title") {
+                    if (xml.name() == QLatin1String("title")) {
                         group->setTitle(xml.readElementText());
                     }
-                    if (xml.name() == "description") {
+                    if (xml.name() == QLatin1String("description")) {
                         group->setDescription(xml.readElementText());
                     }
-                    if (xml.name() == "phoneme") {
+                    if (xml.name() == QLatin1String("phoneme")) {
                         std::unique_ptr<Phoneme> phoneme = std::unique_ptr<Phoneme>(new Phoneme);
-                        while (xml.readNext() && !xml.atEnd() && xml.name() != "phoneme") {
-                            if (xml.name() == "id") {
+                        while (xml.readNext() && !xml.atEnd() && xml.name() != QLatin1String("phoneme")) {
+                            if (xml.name() == QLatin1String("id")) {
                                 phoneme->setId(xml.readElementText());
                             }
-                            if (xml.name() == "title") {
+                            if (xml.name() == QLatin1String("title")) {
                                 phoneme->setTitle(xml.readElementText());
                             }
                         }
@@ -89,7 +86,7 @@ void Language::setId(const QString &id)
 {
     if (id != m_id) {
         m_id = id;
-        emit idChanged();
+        Q_EMIT idChanged();
     }
 }
 
@@ -102,13 +99,13 @@ void Language::setTitle(const QString &title)
 {
     if (QString::compare(title, m_title) != 0) {
         m_title = title;
-        emit titleChanged();
+        Q_EMIT titleChanged();
     }
 }
 
 QString Language::i18nTitle() const
 {
-    return i18n(m_i18nTitle.toUtf8());
+    return i18n(m_i18nTitle.toUtf8().data());
 }
 
 void Language::seti18nTitle(const QString &title)
@@ -117,7 +114,7 @@ void Language::seti18nTitle(const QString &title)
         return;
     }
     m_i18nTitle = title;
-    emit i18nTitleChanged();
+    Q_EMIT i18nTitleChanged();
 }
 
 QUrl Language::file() const
