@@ -1,6 +1,5 @@
 /*
     SPDX-FileCopyrightText: 2013 Andreas Cord-Landwehr <cordlandwehr@kde.org>
-
     SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */
 
@@ -8,6 +7,7 @@
 #include "artikulate_debug.h"
 #include "icourse.h"
 #include "unit.h"
+#include <QFileInfo>
 #include <QQmlEngine>
 
 Phrase::Phrase()
@@ -58,7 +58,7 @@ void Phrase::setId(QString id)
 {
     if (id != m_id) {
         m_id = std::move(id);
-        emit idChanged();
+        Q_EMIT idChanged();
     }
 }
 
@@ -81,7 +81,7 @@ void Phrase::setText(QString text)
 {
     if (QString::compare(text, m_text) != 0) {
         m_text = text.trimmed();
-        emit textChanged();
+        Q_EMIT textChanged();
     }
 }
 
@@ -95,7 +95,7 @@ void Phrase::seti18nText(QString text)
     if (QString::compare(text, m_i18nText) != 0) {
         // copy unmodified original text string
         m_i18nText = std::move(text);
-        emit i18nTextChanged();
+        Q_EMIT i18nTextChanged();
     }
 }
 
@@ -107,16 +107,16 @@ Phrase::Type Phrase::type() const
 QString Phrase::typeString() const
 {
     switch (m_type) {
-        case IPhrase::Type::Word:
-            return QStringLiteral("word");
-        case IPhrase::Type::Expression:
-            return QStringLiteral("expression");
-        case IPhrase::Type::Sentence:
-            return QStringLiteral("sentence");
-        case IPhrase::Type::Paragraph:
-            return QStringLiteral("paragraph");
-        default:
-            return QStringLiteral("ERROR_UNKNOWN_TYPE");
+    case IPhrase::Type::Word:
+        return QStringLiteral("word");
+    case IPhrase::Type::Expression:
+        return QStringLiteral("expression");
+    case IPhrase::Type::Sentence:
+        return QStringLiteral("sentence");
+    case IPhrase::Type::Paragraph:
+        return QStringLiteral("paragraph");
+    default:
+        return QStringLiteral("ERROR_UNKNOWN_TYPE");
     }
 }
 
@@ -126,7 +126,7 @@ void Phrase::setType(Phrase::Type type)
         return;
     }
     m_type = type;
-    emit typeChanged();
+    Q_EMIT typeChanged();
 }
 
 void Phrase::setType(const QString &typeString)
@@ -159,12 +159,12 @@ Phrase::EditState Phrase::editState() const
 QString Phrase::editStateString() const
 {
     switch (m_editState) {
-        case IEditablePhrase::EditState::Unknown:
-            return QStringLiteral("unknown");
-        case IEditablePhrase::EditState::Translated:
-            return QStringLiteral("translated");
-        case IEditablePhrase::EditState::Completed:
-            return QStringLiteral("completed");
+    case IEditablePhrase::EditState::Unknown:
+        return QStringLiteral("unknown");
+    case IEditablePhrase::EditState::Translated:
+        return QStringLiteral("translated");
+    case IEditablePhrase::EditState::Completed:
+        return QStringLiteral("completed");
     }
     Q_UNREACHABLE();
 }
@@ -175,7 +175,7 @@ void Phrase::setEditState(Phrase::EditState state)
         return;
     }
     m_editState = state;
-    emit editStateChanged();
+    Q_EMIT editStateChanged();
 }
 
 void Phrase::setEditState(const QString &stateString)
@@ -211,7 +211,81 @@ void Phrase::setUnit(std::shared_ptr<IUnit> unit)
         return;
     }
     m_unit = unit;
-    emit unitChanged();
+    Q_EMIT unitChanged();
+}
+
+std::shared_ptr<IPhrase> Phrase::next() const
+{
+    if (m_unit.lock() == nullptr) {
+        qCritical() << "Phrase has no unit parent, abort previous computation";
+        return std::shared_ptr<IPhrase>();
+    }
+    qsizetype phraseIndex{0};
+    auto unitPhrases = m_unit.lock()->phrases();
+    for (qsizetype i = 0; i < unitPhrases.size(); ++i) {
+        if (unitPhrases.at(i).get() == this) {
+            phraseIndex = i;
+            break;
+        }
+    }
+    if (phraseIndex < unitPhrases.size() - 1) {
+        return unitPhrases.at(phraseIndex + 1);
+    } else {
+        qsizetype unitIndex{0};
+        auto unit = m_unit.lock();
+        if (!unit || !unit->course()) {
+            qCritical() << "could not obtain unit or parent course, aborting" << unit->course().get();
+            return std::shared_ptr<IPhrase>();
+        }
+        auto units = unit->course()->units();
+        for (qsizetype i = 0; i < units.size(); ++i) {
+            if (units.at(i).get() == unit.get()) {
+                unitIndex = i;
+                break;
+            }
+        }
+        if (unitIndex < units.size() - 1 && !units.at(unitIndex + 1)->phrases().isEmpty()) {
+            return units.at(unitIndex + 1)->phrases().first();
+        }
+    }
+    return std::shared_ptr<IPhrase>();
+}
+
+std::shared_ptr<IPhrase> Phrase::previous() const
+{
+    if (m_unit.lock() == nullptr) {
+        qCritical() << "Phrase has no unit parent, abort previous computation";
+        return std::shared_ptr<IPhrase>();
+    }
+    qsizetype phraseIndex{0};
+    auto unitPhrases = m_unit.lock()->phrases();
+    for (qsizetype i = 0; i < unitPhrases.size(); ++i) {
+        if (unitPhrases.at(i).get() == this) {
+            phraseIndex = i;
+            break;
+        }
+    }
+    if (phraseIndex > 0) {
+        return unitPhrases.at(phraseIndex - 1);
+    } else {
+        qsizetype unitIndex{0};
+        auto unit = m_unit.lock();
+        if (!unit || !unit->course()) {
+            qCritical() << "could not obtain unit or parent course, aborting";
+            return std::shared_ptr<IPhrase>();
+        }
+        auto units = unit->course()->units();
+        for (qsizetype i = 0; i < units.size(); ++i) {
+            if (units.at(i).get() == unit.get()) {
+                unitIndex = i;
+                break;
+            }
+        }
+        if (unitIndex > 0 && !units.at(unitIndex - 1)->phrases().isEmpty()) {
+            return units.at(unitIndex - 1)->phrases().last();
+        }
+    }
+    return std::shared_ptr<IPhrase>();
 }
 
 QUrl Phrase::sound() const
@@ -226,31 +300,25 @@ void Phrase::setSound(QUrl soundFile)
         return;
     }
     m_nativeSoundFile = std::move(soundFile);
-    emit soundChanged();
-}
-
-QString Phrase::soundFileUrl() const
-{
-    return m_nativeSoundFile.toLocalFile();
+    Q_EMIT soundChanged();
 }
 
 QString Phrase::soundFileOutputPath() const
 {
     if (m_nativeSoundFile.isEmpty()) {
-        QString outputDir = m_unit.lock()->course()->file().path() + '/';
-        // TODO take care that this is proper ASCII
-        return outputDir + id() + ".ogg";
+        const QFileInfo info(m_unit.lock()->course()->file().path());
+        return info.absolutePath() + '/' + id() + QStringLiteral(".ogg");
     } else {
-        return soundFileUrl();
+        return m_nativeSoundFile.toLocalFile();
     }
 }
 
-void Phrase::setSoundFileUrl()
+void Phrase::markSoundRecorded()
 {
     if (soundFileOutputPath() != m_nativeSoundFile.toLocalFile()) {
         m_nativeSoundFile = QUrl::fromLocalFile(soundFileOutputPath());
-        emit soundChanged();
-        emit modified();
+        Q_EMIT soundChanged();
+        Q_EMIT modified();
     }
 }
 
@@ -265,7 +333,7 @@ void Phrase::setExcluded(bool excluded)
         return;
     }
     m_excludedFromUnit = excluded;
-    emit excludedChanged();
+    Q_EMIT excludedChanged();
 }
 
 int Phrase::progress() const
@@ -283,7 +351,7 @@ void Phrase::setProgress(int value)
         return;
     }
     m_trainingProgress = static_cast<uint>(value);
-    emit progressChanged();
+    Q_EMIT progressChanged();
 }
 void Phrase::updateProgress(Phrase::Progress progress)
 {
@@ -294,7 +362,7 @@ void Phrase::updateProgress(Phrase::Progress progress)
         m_skipCounter = 0;
         if (m_trainingProgress < 3) {
             ++m_trainingProgress;
-            emit progressChanged();
+            Q_EMIT progressChanged();
         }
         return;
     }
@@ -302,7 +370,7 @@ void Phrase::updateProgress(Phrase::Progress progress)
         ++m_skipCounter;
         if (m_skipCounter > 2 && m_trainingProgress > 0) {
             --m_trainingProgress;
-            emit progressChanged();
+            Q_EMIT progressChanged();
         }
         return;
     }
@@ -322,7 +390,7 @@ void Phrase::addPhoneme(Phoneme *phoneme)
 {
     if (!m_phonemes.contains(phoneme)) {
         m_phonemes.append(phoneme);
-        emit phonemesChanged();
+        Q_EMIT phonemesChanged();
         // FIXME tell Unit to also send corresponding signal!
     }
 }
@@ -330,7 +398,7 @@ void Phrase::addPhoneme(Phoneme *phoneme)
 void Phrase::removePhoneme(Phoneme *phoneme)
 {
     if (m_phonemes.removeOne(phoneme)) {
-        emit phonemesChanged();
+        Q_EMIT phonemesChanged();
         // FIXME tell Unit to also send corresponding signal!
     }
 }
