@@ -1,13 +1,10 @@
 /*
-    SPDX-FileCopyrightText: 2013-2015 Andreas Cord-Landwehr <cordlandwehr@kde.org>
-
+    SPDX-FileCopyrightText: 2013-2025 Andreas Cord-Landwehr <cordlandwehr@kde.org>
     SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */
 
 #include "mainwindow.h"
 #include "application.h"
-#include "artikulate_debug.h"
-#include "libsound/src/outputdevicecontroller.h"
 #include "settings.h"
 #include <KAboutData>
 #include <KLocalizedContext>
@@ -19,17 +16,13 @@ using namespace LearnerProfile;
 
 MainWindow::MainWindow()
     : m_profileManager(this)
-    , m_trainingSession(&m_profileManager, this)
 {
     rootContext()->setContextObject(new KLocalizedContext(this));
 
-    // set view
-    rootContext()->setContextProperty(QStringLiteral("g_trainingSession"), &m_trainingSession);
-    rootContext()->setContextProperty(QStringLiteral("g_profileManager"), &m_profileManager);
-    rootContext()->setContextProperty(QStringLiteral("g_artikulateAboutData"), QVariant::fromValue(KAboutData::applicationData()));
-
     // set starting screen
-    load(QUrl(QStringLiteral("qrc:/artikulate/qml/Main.qml")));
+    QVariantMap initialProperties{{"aboutData", QVariant::fromValue(KAboutData::applicationData())}};
+    setInitialProperties(initialProperties);
+    load(":/qt/qml/org/kde/artikulate/Main.qml");
 
     // create training profile if none exists:
     if (!m_profileManager.activeProfile()) {
